Clojure only.

vaelii.impl.types.solve

The Solver protocol and the Program record a solve is handed, as a held namespace (vaelii.impl.types.prover states what that means). The local solver behind the protocol, and program, which builds a Program from a KB, are vaelii.impl.solve.

The `Solver` protocol and the `Program` record a solve is handed, as a held namespace
(`vaelii.impl.types.prover` states what that means).  The local solver behind the
protocol, and `program`, which builds a `Program` from a KB, are `vaelii.impl.solve`.
raw docstring

Solvercljprotocol

solveclj

(solve solver program)

Assign truth to program's contested assumptions. Return {:defeat #{handle ...} ; assumptions to disbelieve :violated [nogood ...]} ; contradictions left unsatisfiable (the result)

Assign truth to `program`'s contested assumptions.  Return
{:defeat   #{handle ...}   ; assumptions to disbelieve
 :violated [nogood ...]}   ; contradictions left unsatisfiable (the result)
source

cljdoc builds & hosts documentation for Clojure/Script libraries