vaelii.impl.types.store

The storage records with no methods (Kind, TokenLog, Oplog), as a held namespace (vaelii.impl.types.prover states what that means), with the notes on their fields.

A store with methods — a record store, an index store, a key-value backend — is defined, with its methods inline, in the namespace that implements it (vaelii.impl.memory, vaelii.impl.kv, vaelii.impl.disk.kv, …).

The storage records with no methods (`Kind`, `TokenLog`, `Oplog`), as a held namespace
(`vaelii.impl.types.prover` states what that means), with the notes on their fields.

A store with methods — a record store, an index store, a key-value backend — is defined,
with its methods inline, in the namespace that implements it (`vaelii.impl.memory`,
`vaelii.impl.kv`, `vaelii.impl.disk.kv`, …).
raw docstring

No vars found in this namespace.

cljdoc builds & hosts documentation for Clojure/Script libraries