Interval duration arithmetic: DurationProver answers (totalDuration (list I1 I2 …) D)
and (overlapDuration I1 I2 D) from the stored (length I M) facts, on [lo hi]
magnitude bounds, with the overlap sharpened by stp/overlap-window-with-support.
Opt-in, as the :duration reasoner. See docs/duration.md.
Interval duration arithmetic: `DurationProver` answers `(totalDuration (list I1 I2 …) D)` and `(overlapDuration I1 I2 D)` from the stored `(length I M)` facts, on `[lo hi]` magnitude bounds, with the overlap sharpened by `stp/overlap-window-with-support`. Opt-in, as the `:duration` reasoner. See docs/duration.md.
The two computed predicates this prover answers — neither ever stored.
The two computed predicates this prover answers — neither ever stored.
(duration-prover)The interval-duration arithmetic prover, registered as the :duration reasoner.
The interval-duration arithmetic prover, registered as the `:duration` reasoner.
(overlap-bounds rels [lo1 hi1] [lo2 hi2])The [lo hi] overlap of two intervals, given the Allen relations rels still possible
between them and each one's [lo hi] length:
rels within temporallyDisjoint — [0 0];subintervalOf — the first length;hasSubinterval — the second length;[0, min(hi1, hi2)].Nil for an empty rels, which is an inconsistent network.
The `[lo hi]` overlap of two intervals, given the Allen relations `rels` still possible between them and each one's `[lo hi]` length: * `rels` within `temporallyDisjoint` — `[0 0]`; * within `subintervalOf` — the first length; * within `hasSubinterval` — the second length; * otherwise `[0, min(hi1, hi2)]`. Nil for an empty `rels`, which is an inconsistent network.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |