Relation algebras of nine relations, each a pair of coordinates on two independent axes
of the one-dimensional point algebra: the cardinal directions (vaelii.impl.orientation)
and the relative frame (vaelii.impl.relative). algebra derives universe, identity,
composition and converse from one projection table. See docs/space.md and docs/qcn.md.
Relation algebras of nine relations, each a pair of coordinates on two independent axes of the one-dimensional point algebra: the cardinal directions (`vaelii.impl.orientation`) and the relative frame (`vaelii.impl.relative`). `algebra` derives universe, identity, composition and converse from one projection table. See docs/space.md and docs/qcn.md.
(algebra relation->axes)The vaelii.impl.qcn relation algebra {:universe :identity :compose :converse} of
relation->axes, a map of base relation → its [axis-1 axis-2] projection. The
identity is the relation projecting to [:eq :eq]. Throws :bad-algebra unless the
projection is a bijection onto the nine axis pairs.
The `vaelii.impl.qcn` relation algebra `{:universe :identity :compose :converse}` of
`relation->axes`, a map of base relation → its `[axis-1 axis-2]` projection. The
identity is the relation projecting to `[:eq :eq]`. Throws `:bad-algebra` unless the
projection is a bijection onto the nine axis pairs.The one-dimensional point algebra: [a b] → the relations possible between x and z
when a relates x to y and b relates y to z.
The one-dimensional point algebra: `[a b]` → the relations possible between x and z when a relates x to y and b relates y to z.
The one-dimensional point algebra's converse: reading a relation backwards flips it.
The one-dimensional point algebra's converse: reading a relation backwards flips it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |