The KB record, as a held namespace (vaelii.impl.types.prover states what that means).
A reload that redefined it would leave every open KB an instance of a class the reloaded
code no longer constructs. Opening, closing and every operation on a KB is
vaelii.impl.kb.
The KB record, as a held namespace (`vaelii.impl.types.prover` states what that means). A reload that redefined it would leave every open KB an instance of a class the reloaded code no longer constructs. Opening, closing and every operation on a KB is `vaelii.impl.kb`.
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |