The Solver protocol and the Program record a solve is handed, as a held namespace
(vaelii.impl.types.prover states what that means). The local solver behind the
protocol, and program, which builds a Program from a KB, are vaelii.impl.solve.
The `Solver` protocol and the `Program` record a solve is handed, as a held namespace (`vaelii.impl.types.prover` states what that means). The local solver behind the protocol, and `program`, which builds a `Program` from a KB, are `vaelii.impl.solve`.
(solve solver program)Assign truth to program's contested assumptions. Return
{:defeat #{handle ...} ; assumptions to disbelieve
:violated [nogood ...]} ; contradictions left unsatisfiable (the result)
Assign truth to `program`'s contested assumptions. Return
{:defeat #{handle ...} ; assumptions to disbelieve
:violated [nogood ...]} ; contradictions left unsatisfiable (the result)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |