The storage records with no methods (Kind, TokenLog, Oplog), as a held namespace
(vaelii.impl.types.prover states what that means), with the notes on their fields.
A store with methods — a record store, an index store, a key-value backend — is defined,
with its methods inline, in the namespace that implements it (vaelii.impl.memory,
vaelii.impl.kv, vaelii.impl.disk.kv, …).
The storage records with no methods (`Kind`, `TokenLog`, `Oplog`), as a held namespace (`vaelii.impl.types.prover` states what that means), with the notes on their fields. A store with methods — a record store, an index store, a key-value backend — is defined, with its methods inline, in the namespace that implements it (`vaelii.impl.memory`, `vaelii.impl.kv`, `vaelii.impl.disk.kv`, …).
No vars found in this namespace.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |